@@ -1,15 +1,15 @@
 use miniconf::{Miniconf, MqttClient};
-use minimq::{Minimq, QoS};
+use minimq::{Minimq, QoS, Retain};
 use std::time::Duration;
 use std_embedded_nal::Stack;
 use std_embedded_time::StandardClock;
 
-#[derive(Default, Miniconf, Debug)]
+#[derive(Clone, Default, Miniconf, Debug)]
 struct NestedSettings {
     frame_rate: u32,
 }
 
-#[derive(Default, Miniconf, Debug)]
+#[derive(Clone, Default, Miniconf, Debug)]
 struct Settings {
     inner: NestedSettings,
     amplitude: [f32; 2],
@@ -42,6 +42,7 @@ async fn mqtt_client() {
             "sample/prefix/settings/amplitude/0",
             b"32.4",
             QoS::AtMostOnce,
+            Retain::NotRetained,
             &[],
         )
         .unwrap();
@@ -52,13 +53,20 @@ async fn mqtt_client() {
             "sample/prefix/settings/inner/frame_rate",
             b"10",
             QoS::AtMostOnce,
+            Retain::NotRetained,
             &[],
         )
         .unwrap();
     tokio::time::sleep(Duration::from_millis(100)).await;
 
     mqtt.client
-        .publish("sample/prefix/settings/exit", b"true", QoS::AtMostOnce, &[])
+        .publish(
+            "sample/prefix/settings/exit",
+            b"true",
+            QoS::AtMostOnce,
+            Retain::NotRetained,
+            &[],
+        )
         .unwrap();
 }
 
@@ -67,12 +75,13 @@ async fn main() {
     // Spawn a task to send MQTT messages.
     tokio::task::spawn(async move { mqtt_client().await });
 
-    let mut client: MqttClient<Settings, Stack, StandardClock, 256, 1> = MqttClient::new(
+    let mut client: MqttClient<Settings, Stack, StandardClock, 256> = MqttClient::new(
         Stack::default(),
         "",
         "sample/prefix",
         "127.0.0.1".parse().unwrap(),
         StandardClock::default(),
+        Settings::default(),
     )
     .unwrap();
 
