@@ -1,15 +1,15 @@
 use miniconf::Miniconf;
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 
 #[test]
 fn simple_enum() {
-    #[derive(Miniconf, Debug, Deserialize, PartialEq)]
+    #[derive(Miniconf, Debug, Deserialize, Serialize, PartialEq)]
     enum Variant {
         A,
         B,
     }
 
-    #[derive(Miniconf, Debug, Deserialize)]
+    #[derive(Miniconf, Debug, Deserialize, Serialize)]
     struct S {
         v: Variant,
     }
@@ -21,11 +21,16 @@ fn simple_enum() {
     s.string_set(field, "\"B\"".as_bytes()).unwrap();
 
     assert_eq!(s.v, Variant::B);
+
+    // Test metadata
+    let metadata = s.get_metadata();
+    assert_eq!(metadata.max_depth, 2);
+    assert_eq!(metadata.max_topic_size, "v".len());
 }
 
 #[test]
 fn invalid_enum() {
-    #[derive(Miniconf, Debug, Deserialize, PartialEq)]
+    #[derive(Miniconf, Debug, Serialize, Deserialize, PartialEq)]
     enum Variant {
         A,
         B,
