@@ -1,5 +1,8 @@
 use machine::*;
-use miniconf::{minimq::QoS, Miniconf};
+use miniconf::{
+    minimq::{QoS, Retain},
+    Miniconf,
+};
 use serde::Deserialize;
 use std_embedded_nal::Stack;
 use std_embedded_time::StandardClock;
@@ -7,12 +10,12 @@ use std_embedded_time::StandardClock;
 #[macro_use]
 extern crate log;
 
-#[derive(Debug, Default, Miniconf, Deserialize)]
+#[derive(Clone, Debug, Default, Miniconf, Deserialize)]
 struct AdditionalSettings {
     inner: u8,
 }
 
-#[derive(Debug, Default, Miniconf, Deserialize)]
+#[derive(Clone, Debug, Default, Miniconf, Deserialize)]
 struct Settings {
     data: u32,
     more: AdditionalSettings,
@@ -97,12 +100,13 @@ fn main() -> std::io::Result<()> {
     .unwrap();
 
     // Construct a settings configuration interface.
-    let mut interface: miniconf::MqttClient<Settings, _, _, 256, 1> = miniconf::MqttClient::new(
+    let mut interface: miniconf::MqttClient<Settings, _, _, 256> = miniconf::MqttClient::new(
         Stack::default(),
         "",
         "device",
         localhost,
         StandardClock::default(),
+        Settings::default(),
     )
     .unwrap();
 
@@ -133,6 +137,7 @@ fn main() -> std::io::Result<()> {
                             "device/settings/data",
                             "500".as_bytes(),
                             QoS::AtMostOnce,
+                            Retain::NotRetained,
                             &[],
                         )
                         .unwrap();
@@ -150,6 +155,7 @@ fn main() -> std::io::Result<()> {
                             "device/settings/more/inner",
                             "100".as_bytes(),
                             QoS::AtMostOnce,
+                            Retain::NotRetained,
                             &[],
                         )
                         .unwrap();
